<?php

/**
 * @file
 * Administrative actions
 */

/**
 * Admin settings form
 */
function dropfort_update_admin_form($form, &$form_state) {
  $form['dropfort_update_base_url'] = array(
    '#type' => 'textfield',
    '#title' => t('Base URL'),
    '#description' => t('Base URL to your Dropfort instance. <em>Defaults to @url</em>', array('@url' => DROPFORT_UPDATE_BASE_URL)),
    '#size' => 40,
    '#maxlength' => 255,
    '#default_value' => variable_get('dropfort_update_base_url', DROPFORT_UPDATE_BASE_URL),
  );

  $form['dropfort_registration_link'] = array(
    '#prefix' => '<div><strong>' . t('Registration') . '</strong></div>',
    '#markup' => _dropfort_update_site_registration_link(),
    '#suffix' => '<p><em>' . t("If you haven't done so already, register your site with Dropfort") . '</em></p>',
  );

  $form['dropfort_update_show_moderation_notice'] = array(
    '#type' => 'checkbox',
    '#title' => t('Show moderation notice'),
    '#description' => t('Show a notification on update report pages that the list of updates are being moderated.'),
    '#default_value' => variable_get('dropfort_update_show_moderation_notice', FALSE),
  );

  $form['advanced_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Advanced Settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
    '#access' => user_access('administer dropfort_update'),
  );

  $form['advanced_settings']['dropfort_update_site_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Site Identifier'),
    '#disabled' => TRUE,
    '#size' => 70,
    '#default_value' => _dropfort_update_get_private_key(),
    '#description' => t('This is your sites unique install ID. Use this to register your site on Dropfort.com'),
  );

  $form['advanced_settings']['dropfort_update_site_token'] = array(
    '#type' => 'textfield',
    '#title' => t('Site Token'),
    '#description' => t('Randomly generated token to allow access to your site to Dropfort.com. You may regenerate this key at any time however you must update your site information on Dropfort.com to match.'),
    '#size' => 70,
    '#default_value' => variable_get('dropfort_update_site_token'),
    '#maxlength' => 255,
    '#disabled' => TRUE,
  );

  $form['advanced_settings']['dropfort_update_generate_new_site_token'] = array(
    '#type' => 'checkbox',
    '#title' => t('Generate New Site Token'),
    '#description' => t('When saving the configuration, generate a new site token. Useful when an migrating a site between environments or when the value is no longer secret. <em>N.B. This will clear your cached project update data.</em>'),
    '#default_value' => -1,
  );

  $form['advanced_settings']['dropfort_update_allow_unencrypted'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow unencrypted connections'),
    '#description' => t('Allow update data to be requested via plain HTTP connections. <em>Not recommended</em>'),
    '#default_value' => variable_get('dropfort_update_allow_unencrypted', FALSE),
  );

  $form['advanced_settings']['dropfort_update_timestamp_delta'] = array(
    '#type' => 'textfield',
    '#title' => t('Timestamp delta'),
    '#description' => t('The maximum delta between the Dropfort server time and your site server time (in seconds). This is an absolute value.'),
    '#size' => 26,
    '#maxlength' => 32,
    '#default_value' => DROPFORT_UPDATE_TIMESTAMP_DELTA,
    '#element_validate' => array('element_validate_integer_positive'),
  );

  $form['#validate'][] = 'dropfort_update_admin_validate';
  $form['#submit'][] = 'dropfort_update_admin_submit';
  return system_settings_form($form);
}

/**
 * Validation callback for dropfort admin form
 */
function dropfort_update_admin_validate(&$form, &$form_state) {
  // We don't want to save the site key or site id so we'll remove it from the submitted data
  unset($form_state['values']['dropfort_update_site_token']);
  unset($form_state['values']['dropfort_update_site_id']);
}

/**
 * Submit callback for dropfort admin form
 */
function dropfort_update_admin_submit(&$form, &$form_state) {
  if (isset($form_state['values']['dropfort_update_generate_new_site_token']) and FALSE != $form_state['values']['dropfort_update_generate_new_site_token']) {
    _dropfort_update_generate_new_site_token();
  }
}